==> xiph-qt-0.1.1.tar.gz: xiph-qt-0.1.1/OggImport/src/OggImport.h <==
/*
 *  OggImport.h
 *
 *    OggImport.h - some constants definitions.
 *
 *
 *  Copyright (c) 2005  Arek Korbik
 *
 *  This file is part of XiphQT, the Xiph QuickTime Components.
 *
 *  XiphQT is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  XiphQT is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with XiphQT; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 *  Last modified: $Id: OggImport.h 10322 2005-11-02 11:22:05Z arek $
 *
 */


#ifndef __OGGIMPORT_H__
#define __OGGIMPORT_H__ 1

#include "versions.h"

#define kOggVorbisBundleID "net.barelyfocused.xiph.oggimport"

#define kImporterResID                  4000
#define kImporterNameStringResID        4000
#define kImporterInfoStringResID        4001

#define kSoundComponentManufacturer     'Xiph'	// your company's OSType
#define kCodecFormat                    'OggS'


#ifdef _DEBUG
#define OggImporterName        "Ogg Vorbis Importer"
#else
#define OggImporterName        ""
#endif

#endif /* __OGGIMPORT_H__ */

==> xiph-qt-0.1.1-1.tar.gz: xiph-qt-0.1.1-1/OggImport/src/OggImport.h <==
/*
 *  OggImport.h
 *
 *    OggImport.h - some constants definitions.
 *
 *
 *  Copyright (c) 2005  Arek Korbik
 *
 *  This file is part of XiphQT, the Xiph QuickTime Components.
 *
 *  XiphQT is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  XiphQT is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with XiphQT; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 *  Last modified: $Id: OggImport.h 10322M 2005-11-26 01:32:34Z (local) $
 *
 */


#ifndef __OGGIMPORT_H__
#define __OGGIMPORT_H__ 1

#include "versions.h"

#define kOggVorbisBundleID "org.xiph.xiph-qt.oggimport"

#define kImporterResID                  4000
#define kImporterNameStringResID        4000
#define kImporterInfoStringResID        4001

#define kSoundComponentManufacturer     'Xiph'	// your company's OSType
#define kCodecFormat                    'OggS'


#ifdef _DEBUG
#define OggImporterName        "Ogg Vorbis Importer"
#else
#define OggImporterName        ""
#endif

#endif /* __OGGIMPORT_H__ */
